<!DOCTYPE TS><TS>
<context encoding="UTF-8">
    <name>AboutDialog</name>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Navegador ligero basado en WebKit</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autores</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message encoding="UTF-8">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;(new line)
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;(new line)
p, li { white-space: pre-wrap; }(new line)
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;(new line)
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation>WebKit versión: %1</translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Idiomas</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Idiomas: en orden de preferencia:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover hacia &amp;arriba</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover hacia a&amp;bajo</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Añadir...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation>Bloqueado por la regla AdBlock: %1</translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation>Añadir regla personalizada</translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation>Aprenda más sobre la escritura de reglas...</translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation>Actualizar la subscripción</translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation>Examinar las subscripciones...</translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation>Eliminar la subscripción</translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation>Configuración de AdBlock</translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation>Activar AdBlock</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation>Reglas personalizadas</translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation>Regla</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation>¿Subscribir?</translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation>¿Aceptar esta subscripción AdBlock?
%1</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Añadir marcador</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Escriba un nombre para el marcador y elija dónde quiere guardarlo.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Añadir carpeta</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation>Formulario de contraseñas</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Eliminar todo</translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation>&lt;b&gt;¿Desea guardar esta contraseña?&lt;/b&gt;&lt;br&gt;         Para revisar y eliminar las contraseñas guardadas, abra el panel Autocompletar de Preferencias.</translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation>Nunca para este sitio</translation>
    </message>
    <message>
        <source>Not now</source>
        <translation>Ahora no</translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation>Página web</translation>
    </message>
    <message>
        <source>User Name</source>
        <translation>Nombre de usuario</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Crear carpeta</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Abrir en una pestaña nueva</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nueva carpeta</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Editar nombre</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Editar dirección</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Error al cargar los marcadores en la línea %1, columna %2: %3
</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Barra de herramientas de marcadores</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menú</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Importado %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Guardar archivo</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Error al exportar</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>Error guardando los marcadores</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Eliminar marcador</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Insertar marcador</translation>
    </message>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Barra de marcadores</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Menú de marcadores</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Error al cargar marcadores html: %1
</translation>
    </message>
    <message>
        <source>XBEL</source>
        <translation type="obsolete">XBEL</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation>Cambiar el nombre</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation>Cambiar la dirección</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation>Marcadores XBEL</translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation>Marcadores HTML de Netscape</translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation>Se necesita la herramienta htmlToXBel</translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation>La herramienta htmlToXBel , que se incluye con Arora y es necesaria para importar los marcadores HTML, no está instalada o no está disponible en el camino de búsqueda.</translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation>Cargando marcador</translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation>Se produjo un error mientras se cargaban los marcadores HTML: %1
</translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Abrir en pestañas</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Marcador</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Abrir en una &amp;pestaña nueva</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Añadir marcador...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Añadir carpeta...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Marcadores</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete"> (Cambio: %1 %2)</translation>
    </message>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Hay %1 ventanas y %2 pestañas abiertas
¿Está seguro de que desea salir?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Falló la recuperación</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">La seión guardada no puede ser recuperada ya que Arora falló durante la última recuperación.</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation>Arora se cerró inesperadamente mientras intentaba recuperar esta sesión.  ¿Intentarlo de nuevo?</translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Ventana nueva</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;Abrir archivo...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Abrir &amp;ubicación...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Guardar como...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Importar marcadores...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Exportar marcadores...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>V&amp;ista previa...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Im&amp;primir...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>&amp;Navegación privada...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Deshacer</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Rehacer</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Pegar</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Buscar</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Buscar &amp;sigiente</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Buscar &amp;anterior</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">&amp;Preferencias...</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Mostrar barra de menú</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Shift+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>&amp;Recargar página</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>Código &amp;fuente</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Pantalla &amp;completa</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;Historial</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Adelante</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Recuperar la última sesión</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Marcadores</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Añadir marcador...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventana</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Herramientas</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Buscar en la web</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;Borrar datos privados</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Activar el &amp;inspector web</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;yuda</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navegación</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Mostrar la barra de estado</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Ocultar la barra de estado</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Mostrar la barra de herramientas</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Ocultar la barra de herramientas</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Mostrar barra de marcadores</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Ocultar barra de marcadores</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Abrir un recurso web</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Recursos web (*.html *.htm *.svg *.png *.gif *.svgz);;Todos los archivos (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Imprimir documento</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>¿Está seguro de que quiere activar la navegación privada?</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>¿Está seguro de que quiere cerrar la ventana?  Hay %1 pestañas abiertas</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Inspector web</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>El inspector web sólo funcionará correctamente con las páginas que se carguen después de activarlo.
¿Desea recargar todas las páginas?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Detener la carga de la página actual</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Recargar la página actual</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">Mostrar mo&amp;nitor de red</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Cambiar el idioma de la aplicación </translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Cerrar ventana</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;aumentar</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>Zoom &amp;normal</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;reducir</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Zoom &amp;solo texto</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>Acerca de &amp;%1</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Mostrar todos los marcadores...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Añadir carpeta...</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Al activar la navegación privada, se desactivarán algunas de las medidas relativas a su privacidad:&lt;ul&gt;&lt;li&gt; Las páginas web so serán añadidas al historial.&lt;/li&gt;&lt;li&gt; Se eliminará automáticamente los elementos de la ventana de descargas.&lt;/li&gt;&lt;li&gt; No se añadiran nuevas cookies y las actuales no serán accesibles.&lt;/li&gt;&lt;li&gt; Los iconos de los sitios no se almacenarán, tampoco se guardarán las sesiones.&lt;/li&gt;&lt;li&gt; Las búsquedas no serán añadidas al menú emergente en el cuadro de búsqueda.&lt;/li&gt;&lt;/ul&gt;Podrá hacer clic en los botones Atrás y Adelante para volver a las páginas web que ha abierto solo hasta que se cierre la ventana.</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Codificación del texto</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; Network cache is disabled.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Al activar la navegación privada, se desactivarán algunas de las medidas relativas a su privacidad:&lt;ul&gt;&lt;li&gt; Las páginas web so serán añadidas al historial.&lt;/li&gt;&lt;li&gt; Se eliminará automáticamente los elementos de la ventana de descargas.&lt;/li&gt;&lt;li&gt; No se añadiran nuevas cookies y las actuales no serán accesibles.&lt;/li&gt;&lt;li&gt; Los iconos de los sitios no se almacenarán, tampoco se guardarán las sesiones.&lt;/li&gt;&lt;li&gt; Las búsquedas no serán añadidas al menú emergente en el cuadro de búsqueda.&lt;/li&gt;&lt;/ul&gt;Se desactiva la caché de red.&lt;/li&gt;&lt;/ul&gt;Podrá hacer clic en los botones Atrás y Adelante para volver a las páginas web que ha abierto solo hasta que se cierre la ventana.</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Seleccionar &amp;todo</translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation>Alt+Ctrl+B</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; No new network cache is written to disk.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Al activar la navegación privada, se desactivarán algunas de las medidas relativas a su privacidad:&lt;ul&gt;&lt;li&gt; Las páginas web so serán añadidas al historial..&lt;/li&gt;&lt;li&gt; Se eliminará automáticamente los elementos de la ventana de descargas..&lt;/li&gt;&lt;li&gt; No se añadiran nuevas cookies y las actuales no serán accesibles.&lt;/li&gt;&lt;li&gt; Los iconos de los sitios no se almacenarán, tampoco se guardarán las sesiones.&lt;/li&gt;&lt;li&gt; Las búsquedas no serán añadidas al menú emergente en el cuadro de búsqueda.&lt;/li&gt;&lt;li&gt; La nueva caché de red no se gravará en el disco.&lt;/li&gt;&lt;/ul&gt;Podrá hacer clic en los botones Atrás y Adelante para volver a las páginas web que ha abierto solo hasta que se cierre la ventana.</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opciones...</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation>Configurar los motores de búsqueda...</translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation>&amp;Bloquear publicidad...</translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation>Cuando se activa la navegación privada, se desactivarán algunas acciones relacionadas con su intimidad:</translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation>Las páginas web no se añadirán al historial.</translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation>Se eliminarán automáticamente los elementos de la ventana de descargas.</translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation>No se guardarán las nuevas cookies, no se podrá acceder a las cookies actuales.</translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation>No se guardarán los iconos de la página.</translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation>No se guardará la sesión.</translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation>Las búsquedas no se añadirán al menú emergente en el cuadro de búsquedas.</translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation>No se escribirá en el disco la nueva caché de la red.</translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation>Hasta que se cierre la ventana, usted podrá hacer clic en los botones Atrás y Adelante para volver a las páginas web que ha abierto.</translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation>Navegación privada</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Limpiar datos privados</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Limpiar los siguientes elementos:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>Historial de &amp;navegación</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>Historial de &amp;descargas</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>Historial de &amp;búsquedas</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Cookies</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>Páginas &amp;web en memoria caché</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>&amp;Iconos de los sitios web</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>Limpiar datos &amp;privados</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <source>Load All</source>
        <translation>Cargar todo</translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation>Añadir %1 a la lista blanca</translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation>Quitar de la lista blanca</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation>Cargar «Flash»</translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation>Lista blanca de sitios</translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Regla</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Permitir</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Permitir sólo para esta sesión</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Ruta</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Segura</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Caduca</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Contenidos</translation>
    </message>
    <message>
        <source>true</source>
        <translation>verdadero</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falso</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation>Cookie de la sesión</translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Eliminar &amp;todas las cookies</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation>Añadir &amp;regla</translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Cookies exentas</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Nueva excepción</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Dominio:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Permitir sólo para esta sesión</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Permitir</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Excepciones</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Eliminar &amp;todas</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Vaciar</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 elementos</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formulario</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Icono</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nombre de archivo</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Volver a intentarlo</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Guardar archivo</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Descarga cancelada: %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Error al abrir el archivo de salida: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Error al guardar: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Error de red: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">segundos</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1 de %2 (%3/seg) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 de %2 - Detenida</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 de %2 (%3/sec) - %4</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation>El directorio de descarga (%1)no se puede crear.</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%n Download(s)</source>
        <translation>%n Descarga(s)
        
        
        
        
        
        </translation>
    </message>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Hay %1 descargas en proceso
¿Quiere salir de todos modos?</translation>
    </message>
    <message>
        <source>%n minutes remaining</source>
        <translation>Faltan %n minutos
        
        
        
        
        </translation>
    </message>
    <message>
        <source>%n seconds remaining</source>
        <translation>Faltan %n segundos
        
        
        
        
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation>GB</translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation>Sin error</translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation>Se produjo un error al abrir: %1: No existe el archivo o directorio</translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation>No se puede leer %1</translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation>Contenido de %1</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Eliminar &amp;todo</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Mostrar todo el historial</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Limpiar historial...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Limpiar historial</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>¿Desea limpiar el historial?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Hace un rato</translation>
    </message>
    <message>
        <source>%n item(s)</source>
        <translation>%n elemento(s)
        
        
        
        
        
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation>¡Bienvenido a Arora!</translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation>Iniciar Arora</translation>
    </message>
    <message>
        <source>Search!</source>
        <translation>¡Buscar!</translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation>Resultados de la búsqueda proporcionados por</translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation>Acerca de Arora</translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>Choose language</source>
        <translation>Elegir idioma</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Puede ejecutarse con un idioma distinto&lt;br&gt;al predeterminado del sistema operativo.&lt;/p&gt;&lt;p&gt;Por favor, elija el idioma que desee utilizar&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">Los archivos de traducción no están instalados.</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation>Ho hay archivos de traducción instalados en %1.</translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Introduzca el nombre de usuario y la contraseña para &quot;%1&quot; en %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Conectar al proxy &quot;%1&quot; usando:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation> Errores -SSL</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Errores SSL:&lt;br/&gt;&lt;br/&gt;para: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

¿Ignorar estos errores?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Certificados:&lt;br/&gt;%1&lt;br/&gt;¿Aceptar todos estos certificados?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation>Emisor: %1</translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation>No es válido antes de: %1</translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation>Válido hasta el: %1</translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation>Nombres alternativos:</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Nombre</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Valor</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Monitor de red</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Solicitudes de red</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Cabeceras de las solicitudes</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Cabeceras de respuesta</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Eliminar</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">Eliminar &amp;todas las solicitudes</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation>OpenSearch</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation>%1 no es una descripción correcta para OpenSearch 1.1 o ya está en su lista.</translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation>Debe tener aquí al menos un motor de búsqueda.</translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation>Gestor OpenSearch</translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation>&amp;Restaurar predeterminados</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation>&lt;strong&gt;Descripción:&lt;/strong&gt; %1</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation>&lt;strong&gt;Proporciona sugerencias contextuales&lt;/strong&gt;</translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation>Lista separada por comas de las palabras clave que se puede introducir en la barra seguidas de los términos de búsqueda para buscar con este motor</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Palabras clave</translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation>¿Quiere añadir el siguiente motor a su lista de motores de búsqueda?&lt;br /&gt;&lt;br /&gt;Nombre: %1&lt;br /&gt;Búsquedas en: %2</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Se necesita autenticación</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>ICONO SIMULADO</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>INTRODUCIR TEXTO SIMULADO</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nombre de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>No encontrado</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autenticación con el proxy</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Conectar al proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nombre de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>El archivo no es un archivo XBEL versión 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Título desconocido</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation>Este archivo no es un archivo OpenSearch 1.1.</translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Redirige a: %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Método</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Dirección</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Respuesta</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Longitud</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Tipo de contenido</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Información</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formulario</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation>Resaltar todo</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>Al inicio:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Mostrar mi página de inicio</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Mostrar página en blanco</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Recuperar ventanas y pestañas de la última sesión</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Página de inicio:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Página actual</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Eliminar páginas del historial:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Al cabo de un día</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Al cabo de una semana</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Al cabo de dos semanas</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Al cabo de un mes</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Al cabo de un año</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Manualmente</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Al cerrar la aplicación</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Abrir enlaces desde aplicaciones:</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>En una ventana nueva</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Preguntar en cada caso dónde se quieren guardar</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Usar este destino:</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Fuente estándar:</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Seleccionar...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Fuente de anchura fija:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privacidad</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Contenido web</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Activar plugins</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Activar javascript</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Ver imagenes</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Aceptar cookies:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Siempre</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Sólo desde los sitios que visite</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Excepciones...</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Mantener las cookies:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>Hasta que caduquen</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Hasta que cierre la aplicación</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>90 días como máximo</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Cookies...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Pestañas</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Seleccionar pestañas y ventanas al ser creadas</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Usar un sevidor proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Nombre de la máquina:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Puerto:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Nombre de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Hoja de estilos:</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Mostrar sólo un botón de cierre en lugar de uno para cada pestaña</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Bloquear ventanas emergentes</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Abiendo enlaces</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Enlaces que desea abrir en una nueva ventana:</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>En la pestaña seleccionada en la ventana actual</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>En una nueva pestaña en la ventana actual</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>En la pestaña actual</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>Http (Seguro)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>Http (Transparente)</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Idiomas preferidos para visualizar páginas web en:</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation>Use ClickToFlash en las extensiones flash</translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation>Filtrar las cookies de seguimiento</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation>Pedir confirmación cuando se cierren multiples pestañas o ventanas</translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation>Salir de la aplicación cuando se cierre la última pestaña</translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation>Activar caché de red</translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation>Tamaño máximo:</translation>
    </message>
    <message>
        <source> MB</source>
        <translation> MB</translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation>Use el motor de búsqueda predeterminado como último recurso cuando la URL dada por el usuario no es correcta</translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation>Elegir directorio...</translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation>Una cookie de sesión caduca:</translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation>Cuando salga de la aplicación</translation>
    </message>
    <message>
        <source>1 day</source>
        <translation>1 día</translation>
    </message>
    <message>
        <source>2 days</source>
        <translation>2 días</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 días</translation>
    </message>
    <message>
        <source>7 days</source>
        <translation>7 días</translation>
    </message>
    <message>
        <source>30 days</source>
        <translation>30 días</translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation>Autocompletar</translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation>Autocompletar formularios web:</translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation>Nombres de usuario y contraseñas</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Editar...</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Examinar...</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation>Se necesita reiniciar</translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation>La configuración de la caché de red ha cambiado. A fin de que pueda ser tenida en cuenta, el navegador tiene que ser reiniciado.</translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation>Elegir directorio</translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation>Elegir archivo CSS</translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Buscar</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">A&amp;justar las líneas</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Código fuente de la página </translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation>Código fuente de la página %1</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>Mostrar barra de pestañas</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Ocultar barra de pestañas</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Duplicar pestaña</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Cerrar pestaña</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Cerrar las &amp;otras pestañas</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Recargar pestaña</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Recargar todas las pestañas</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nueva &amp;pestaña</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Cerrar pestaña</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Mostrar pestaña siguiente</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Mostrar pestaña anterior</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Pestañas cerradas recientemente</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>¿Está seguro de que quiere cerrar esta página?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Ha modificado esta página y si la cierre perderá los cambios.
¿Está seguro de que quiere cerrar esta página?
</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation>Ctrl-]</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation>Ctrl-[</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Pestañas guardadas</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Cargando %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>Carga finalizada</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Hubo un fallo durantre la carga</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Todas las pestañas a marcadores</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>No Recent Searches</source>
        <translation>No hay búsquedas recientes</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Búsquedas recientes</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Limpiar búsquedas recientes</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation>Añadir «%1»</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="obsolete">Configurar motores de búsqueda...</translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Error al cargar la página: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>Cuando se conecta a: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Compruebe que no hay errores en la dirección como&lt;b&gt;ww&lt;/b&gt;.arora-browser.org en lugar de &lt;b&gt;www&lt;/b&gt;.arora-browser.org</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Si su ordenador o red están protegidos por un cortafuegos o un proxy, asegúrese de que al navegador se le permite el acceso a la red.</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Si la dirección es correcta, compruebe la conexión de red.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation>Reenviar una solicitud POST</translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation>Para mostrar el sitio web, la solicitud, junto con todos los datos deben ser enviados, una vez más, lo que puede llevar a algun comportamiento inesperado del sitio por ejemplo, la misma acción puede ser realizada una vez más. ¿Quiere continuar igualmente?</translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Abrir en una &amp;ventana nueva</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Abrir en una &amp;pestaña nueva</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>&amp;Guardar enlace</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>&amp;Añadir esta página a marcadores</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Copiar dirección del enlace</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Abrir &amp;imagen en una ventana nueva</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Abrir i&amp;magen en una pestaña nueva</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>G&amp;uardar imagen</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Co&amp;piar imagen</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>Copiar &amp;dirección de la imagen</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation>Buscar con...</translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation>Añadir a la barra de herramientas de búsqueda</translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation>Método no compatible</translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation>El método %1 no es compatible.</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Motor de búsqueda</translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation>Elija el motor de búsqueda deseado</translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation>Nombre del motor</translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation>Escriba un nombre para el motor</translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation>Bloquear imagen</translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>No encontrado</translation>
    </message>
</context>
</TS>
